<template>
  <div class="system-add-user-container">
    <el-dialog :title="title" v-model="isShowDialog" width="50%">
      <el-form :model="form" size="default" ref="formRef" :rules="rules" label-width="160px">
        <el-row :gutter="35">
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="工艺名称" prop="craftName">
              <el-input v-model.trim="form.craftName" placeholder="工艺名称" clearable></el-input>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="工艺简介" prop="craftContent">
              <el-input v-model.trim="form.craftContent" :autosize="{ minRows: 1 }" type="textarea" placeholder="工艺简介" clearable></el-input>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="主要生产设备" prop="mainProdEquip">
              <el-input v-model.trim="form.mainProdEquip" :autosize="{ minRows: 1 }" type="textarea" placeholder="主要生产设备" clearable></el-input>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="重点部位" prop="keyParts">
              <el-input v-model.trim="form.keyParts" placeholder="重点部位" clearable></el-input>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="重大危险源" prop="hazardCode">
              <el-input v-model.trim="form.hazardCode" :autosize="{ minRows: 1 }" type="textarea" placeholder="重大危险源" clearable></el-input>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="涉及的危险化学品">
              <el-input v-model.trim="form.msds" :autosize="{ minRows: 1 }" type="textarea" placeholder="涉及的危险化学品" clearable></el-input>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="工艺危险特点">
              <el-input v-model.trim="form.hazardCharacter" placeholder="工艺危险特点" clearable></el-input>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="重点监控工艺参数指标">
              <el-input v-model.trim="form.parameterIndex" placeholder="重点监控工艺参数指标" clearable></el-input>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="现有安全控制手段">
              <el-input v-model.trim="form.controlMean" placeholder="现有安全控制手段" clearable></el-input>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="反应类型">
              <el-input v-model.trim="form.reactionType" placeholder="反应类型" clearable></el-input>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="重点监控单元">
              <el-input v-model.trim="form.keyMonitorUnit" placeholder="重点监控单元" clearable></el-input>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="工艺图纸">
              <el-upload accept="image/*" multiple list-type="picture-card" :action="uploadUrl" :headers="header" method="post" :on-exceed="showTip" :on-preview="handlePictureCardPreview" :on-success="handleAvatarSuccess" :limit='2' v-model:file-list="fileList" :before-upload="picSize" :on-remove="handleRemove" :before-remove="beforeRemove">
                <el-icon><Plus /></el-icon>
                <template #tip>
                  <div class="el-upload__tip">上传图片尺寸小于2M,最多可上传2张</div>
                </template>
              </el-upload>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <el-dialog v-model="imgDialog">
        <img width="100%" :src="imageUrl" alt="Preview Image" />
      </el-dialog>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="isShowDialog = !isShowDialog" size="default">取 消</el-button>
            <el-button type="primary" v-throttle @click="onSubmit" size="default">确 定</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>

<script lang="ts">
import { reactive, toRefs, onMounted, defineComponent, ref } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import axios from "axios";
import {workApplyApi} from "/@/api/specialWorkSystem/workApply";
import Cookies from "js-cookie";
import {judgeReportApi} from "/@/api/dataUpload/saftyBaseInfo/judgeReport";

// 定义接口来定义对象的类型
interface DataState {
  title: string
  isShowDialog: boolean
  form: {
    uuid: string
    craftName: string
    craftContent: string
    mainProdEquip: string
    keyParts: string
    hazardCode: string
    msds: string
    hazardCharacter: string
    parameterIndex: string
    controlMean: string
    craftDraw: string
    reactionType: string
    keyMonitorUnit: string
  }
  rules:{},
  fileList: [],
  uploadUrl: string,
  header: {},
  imgDialog: boolean,
  imageUrl: string
}

export default defineComponent({
  name: 'reportDialog',
  setup(props, context) {
    const formRef = ref()
    const state = reactive<DataState>({
      title: '',
      isShowDialog: false,
      form: {
        uuid: '',
        craftName: '',
        craftContent: '',
        mainProdEquip: '',
        keyParts: '',
        hazardCode: '',
        msds: '',
        hazardCharacter: '',
        parameterIndex: '',
        controlMean: '',
        craftDraw: '',
        reactionType: '',
        keyMonitorUnit: ''
      },
      rules:{
        craftName: [{ required: true, message: '请填写工艺名称', trigger: 'blur' }],
        craftContent: [{ required: true, message: '请填写工艺简介', trigger: 'blur' }],
        mainProdEquip: [{ required: true, message: '请填写主要生产设备', trigger: 'blur' }],
        keyParts: [{ required: true, message: '请填写重点部位', trigger: 'blur' }],
        hazardCode: [{ required: true, message: '请填写重大危险源', trigger: 'blur' }]
      },
      fileList: [],
      uploadUrl: import.meta.env.VITE_API_URL + '/account/file/upload',
      header: {
        uid: Cookies.get('uid'),
        Authorization: Cookies.get('token')
      },
      imgDialog: false,
      imageUrl: ''
    })

    // 页面加载时
    onMounted(() => {

    })
    // 打开弹窗
    const open = (type: string, data: object) => {
      state.isShowDialog = true;
      if (type === 'add') {
        state.title = '新增上报'
        state.form = {
          uuid: '',
          craftName: '',
          craftContent: '',
          mainProdEquip: '',
          keyParts: '',
          hazardCode: '',
          msds: '',
          hazardCharacter: '',
          parameterIndex: '',
          controlMean: '',
          craftDraw: '',
          reactionType: '',
          keyMonitorUnit: ''
        }
        state.fileList=[]
      }else{
        state.title = '重新上报'
        Object.keys(state.form).forEach(key => {
          if (Object.prototype.hasOwnProperty.call(data,key)) {
            state.form[key] = JSON.parse(JSON.stringify(data))[key];
          }
        })
        if(data.craftDraw !== ''){
          state.fileList = data.craftDraw.split(',').map((i,index) => {
            return {
              url:  i,
              name: i
            }
          })
        }else{
          state.fileList=[]
        }

        // state.form = {
        //   uuid: data.uuid,
        //   craftName: '',
        //   craftContent: '',
        //   mainProdEquip: '',
        //   keyParts: '',
        //   hazardCode: '',
        //   msds: '',
        //   hazardCharacter: '',
        //   parameterIndex: '',
        //   controlMean: '',
        //   craftDraw: '',
        //   reactionType: '',
        //   keyMonitorUnit: ''
        // }
      }
    };

    // 新增修改
    const onSubmit = async () => {
      formRef.value.validate(async (valid:Boolean) => {
        if(valid){
            state.form.craftDraw = state.fileList.map(i=>i.name).join(',')
            const res = await judgeReportApi().addProduct([state.form])
            if(res.data.code == '200'){
              ElMessage({
                type:'success',
                message:'数据上报成功'
              })
              state.isShowDialog = false
              state.fileList = []
            }else{
              ElMessage({
                type:'warning',
                message:res.data.msg
              })
            }
            context.emit('refresh')
        }else{
          ElMessage({
            type:'warning',
            message:'请完善基本信息'
          })
        }
      })
    }

    // 图片上传
    const showTip =()=>{
      ElMessage({
        type: 'warning',
        message: '超出文件上传数量'
      });
    }

    const picSize = async(rawFile: any) => {
      if(rawFile.size / 1024 / 1024 > 2){
        ElMessage({
          type: 'warning',
          message: '文件大小不能超过2M'
        });
        return false
      }
    }

    const handleAvatarSuccess = (res:any, uploadFile: any) => {
      if(res){
        uploadFile.name = res
      }else{
        ElMessage({
          type: 'warning',
          message: '文件上传失败'
        })
      }
    }

    const handlePictureCardPreview = (uploadFile) => {
      state.imageUrl = uploadFile.url
      state.imgDialog = true;
    }

    const handleRemove = (file, uploadFiles,type) => {
      state.fileList = uploadFiles
    }


    return {
      formRef,
      showTip,
      picSize,
      handleAvatarSuccess,
      handlePictureCardPreview,
      handleRemove,
      open,
      onSubmit,
      ...toRefs(state)
    };
  }
});
</script>
